import { cut } from '@node-rs/jieba';

function splitParagraphs(text) {
  return text.split(/[\f\n\r\t\v]+/);
}

function splitSentences(text, options) {
  switch (options.lang) {
    case "zh":
      return text.match(/[^。？！；]+[。？！；]*[\p{P}]*/g);
    default:
      return text.match(/[^.?!;]+[.?!;]*([\x20]*)/g);
  }
}

function splitPhrases(text, options) {
  switch (options.lang) {
    case "zh":
      return text.match(/[^，。？！；]+[。？！；]*[\p{P}]*/g);
    default:
      return text.match(/[^,.?!;]+[.?!;]*([\x20]*)/g);
  }
}

function splitWord(text, options) {
  switch (options.lang) {
    case "zh":
      return cut(text, true);
    default:
      return text.split(/(\x20|[.?!;]+\x20)/g);
  }
}

function createSegmentation(text, options) {
  const { lang } = options;
  switch (options.segmentation) {
    case "paragraphs":
      return splitParagraphs(text);
    case "sentences":
      return splitSentences(text, {
        lang
      });
    case "phrases":
      return splitPhrases(text, {
        lang
      });
    case "words":
      return splitWord(text, {
        lang
      });
  }
}

export { createSegmentation, splitParagraphs, splitPhrases, splitSentences, splitWord };
